@@ -1,7 +1,7 @@
 package Language::Expr::Compiler::js;
 
 our $DATE = '2016-06-17'; # DATE
-our $VERSION = '0.25'; # VERSION
+our $VERSION = '0.26'; # VERSION
 
 use 5.010;
 use strict;
@@ -353,7 +353,7 @@ sub _map_grep_usort {
     } elsif ($which eq 'grep') {
         return "($ary).filter(function(_){ return (TODO-$uuid); })";
     } elsif ($which eq 'usort') {
-        return "($ary).map(function(x) x).sort(function(a, b){ return (TODO-$uuid); })";
+        return "($ary).sort(function(a, b){ return (TODO-$uuid); })";
     }
 }
 
@@ -432,7 +432,7 @@ Language::Expr::Compiler::js - Compile Language::Expr expression to JavaScript
 
 =head1 VERSION
 
-This document describes version 0.25 of Language::Expr::Compiler::js (from Perl distribution Language-Expr), released on 2016-06-17.
+This document describes version 0.26 of Language::Expr::Compiler::js (from Perl distribution Language-Expr), released on 2016-06-17.
 
 =head1 SYNOPSIS
 
