@@ -1,7 +1,7 @@
 package Language::Expr::JS;
 
 our $DATE = '2016-06-17'; # DATE
-our $VERSION = '0.25'; # VERSION
+our $VERSION = '0.26'; # VERSION
 
 use 5.010;
 use strict;
@@ -41,6 +41,9 @@ sub eval_expr_js {
     my $src = join(
         "",
         _comment("expr: $expr\n"),
+        ($opts->{vars} ?
+             _comment("declare vars\n") . join("", map { "let $_ = ".$json->encode($opts->{vars}{$_}).";\n" } sort keys %{$opts->{vars}})
+             : ""),
         "console.log(JSON.stringify(",
         $jsc->compile($expr),
         "))",
@@ -49,8 +52,16 @@ sub eval_expr_js {
     print $jsh $src;
     close($jsh) or die "Can't write JS code to file $jsfn: $!";
 
-    my $out = IPC::System::Options::readpipe($nodejs_path, $jsfn);
-    $json->decode($out);
+    my ($stdout, $stderr);
+    IPC::System::Options::system(
+        {capture_stdout => \$stdout, capture_stderr => \$stderr},
+        $nodejs_path, "--use_strict", "--harmony_scoping", $jsfn,
+    );
+    die "nodejs exists non-zero (".($? >> 8)."): $stderr" if $?;
+    if ($stdout eq "undefined\n") {
+        return undef;
+    }
+    $json->decode($stdout);
 }
 
 1;
@@ -68,7 +79,7 @@ Language::Expr::JS - Evaluate Expr JavaScript code
 
 =head1 VERSION
 
-This document describes version 0.25 of Language::Expr::JS (from Perl distribution Language-Expr), released on 2016-06-17.
+This document describes version 0.26 of Language::Expr::JS (from Perl distribution Language-Expr), released on 2016-06-17.
 
 =head1 SYNOPSIS
 
